@@ -31,6 +31,7 @@ from cinderclient import shell_utils
 from cinderclient import utils
 
 from cinderclient.v2.shell import *  # noqa
+from cinderclient.v2.shell import CheckSizeArgForCreate
 
 FILTER_DEPRECATED = ("This option is deprecated and will be removed in "
                      "newer release. Please use '--filters' option which "
@@ -51,12 +52,12 @@ class AppendFilters(argparse.Action):
            default=None,
            help='Show enabled filters for specified resource. Default=None.')
 def do_list_filters(cs, args):
-        """List enabled filters.
+    """List enabled filters.
 
-        Symbol '~' after filter key means it supports inexact filtering.
-        """
-        filters = cs.resource_filters.list(resource=args.resource)
-        shell_utils.print_resource_filter_list(filters)
+    Symbol '~' after filter key means it supports inexact filtering.
+    """
+    filters = cs.resource_filters.list(resource=args.resource)
+    shell_utils.print_resource_filter_list(filters)
 
 
 @utils.arg('--filters',
@@ -675,6 +676,8 @@ def do_create(cs, args):
         shell_utils._poll_for_status(
             cs.volumes.get, volume.id, info, 'creating', ['available'],
             timeout_period, cs.client.global_request_id, cs.messages)
+        volume = cs.volumes.get(volume.id)
+        info.update(volume._info)
 
     utils.print_dict(info)
 
